import type { SoundModule, SoundModuleParams, Module, ModuleName } from './SoundModule';
import type { OscillatorModuleParams, Glide, GlideParams, GlideType, Oscillator, OscillatorParams, OscillatorCustomType } from './OscillatorModule';
import type { OneshotModuleParams, OneshotSetting, OneshotSettings, OneshotErrorText } from './OneshotModule';
import type { NoiseModuleParams, NoiseType } from './NoiseModule';
import type { AudioModuleParams, AudioBufferSprite } from './AudioModule';
import type { MediaModuleParams } from './MediaModule';
import type { StreamModuleParams, MediaStreamTrackAudioSourceNode } from './StreamModule';
import type { Part, Sequence, MMLSyntaxError, Tree, TokenType, TokenMap, Token, MMLScheduleWorkerMessageEventType, MMLScheduleWorkerMessageEventData } from './MML';
import type { AnalyserParams, Domain, DataType, FFTSize, Visualizer, VisualizerParams, Color, GraphicsApi, Gradient, Gradients, Shape, Font, GraphicsStyles, TimeOverview, TimeOverviewParams, MouseEventTypes, DragMode, DragCallbackFunction, CurrentTimeStyles, Time, TimeParams, FFT, FFTParams, SpectrumScale } from './SoundModule/Analyser';
import type { RecorderParams, RecordType, QuantizationBit, WaveExportType, Frame, Channel, RecorderProcessorMessageEventData } from './SoundModule/Recorder';
import type { AutopannerParams } from './SoundModule/Effectors/Autopanner';
import type { BitCrusherParams } from './SoundModule/Effectors/BitCrusher';
import type { ChorusParams } from './SoundModule/Effectors/Chorus';
import type { CompressorParams } from './SoundModule/Effectors/Compressor';
import type { DelayParams } from './SoundModule/Effectors/Delay';
import type { EnvelopeGenerator, EnvelopeGeneratorParams } from './SoundModule/Effectors/EnvelopeGenerator';
import type { EqualizerParams } from './SoundModule/Effectors/Equalizer';
import type { FilterParams } from './SoundModule/Effectors/Filter';
import type { FlangerParams } from './SoundModule/Effectors/Flanger';
import type { FuzzParams } from './SoundModule/Effectors/Fuzz';
import type { ListenerParams } from './SoundModule/Effectors/Listener';
import type { NoiseGateParams } from './SoundModule/Effectors/NoiseGate';
import type { NoiseSuppressorParams } from './SoundModule/Effectors/NoiseSuppressor';
import type { OverDriveParams } from './SoundModule/Effectors/OverDrive';
import type { PannerParams, Position3D } from './SoundModule/Effectors/Panner';
import type { PhaserParams, PhaserNumberOfStages } from './SoundModule/Effectors/Phaser';
import type { PitchShifterParams } from './SoundModule/Effectors/PitchShifter';
import type { PreampParams, PreampType, PreampCurve } from './SoundModule/Effectors/Preamp';
import type { Marshall, MarshallParams, PreEqualizerParams as MarshallPreEqualizerParams, PostEqualizerParams as MarshallPostEqualizerParams } from './SoundModule/Effectors/Preamps/Marshall';
import type { MesaBoogie, MesaBoogieParams, PreEqualizerParams as MesaBoogiePreEqualizerParams, PostEqualizerParams as MesaBoogiePostEqualizerParams } from './SoundModule/Effectors/Preamps/MesaBoogie';
import type { Fender, FenderParams, PreEqualizerParams as FenderPreEqualizerParams, PostFilterParams as FenderPostFilterParams, SpeakerInches as FenderSpeakerInches } from './SoundModule/Effectors/Preamps/Fender';
import type { CabinetParams } from './SoundModule/Effectors/Preamps/Cabinet';
import type { ReverbParams, ReverbErrorText } from './SoundModule/Effectors/Reverb';
import type { RingmodulatorParams } from './SoundModule/Effectors/Ringmodulator';
import type { StereoParams } from './SoundModule/Effectors/Stereo';
import type { TremoloParams } from './SoundModule/Effectors/Tremolo';
import type { VocalCancelerParams, VocalCancelerAlgorithm } from './SoundModule/Effectors/VocalCanceler';
import type { WahParams } from './SoundModule/Effectors/Wah';
import type { PitchChar, ConvertedTime, FileEvent, FileReaderType, FileReaderErrorText } from './XSound';
import type { FrozenArray, Inputs, Outputs, Parameters } from './worklet';
import './types';
import { SoundModuleProcessor } from './SoundModule';
import { OscillatorModule, OscillatorModuleProcessor } from './OscillatorModule';
import { OneshotModule, OneshotModuleProcessor } from './OneshotModule';
import { NoiseModule, NoiseModuleProcessor } from './NoiseModule';
import { AudioModule, AudioModuleProcessor } from './AudioModule';
import { MediaModule, MediaModuleProcessor } from './MediaModule';
import { StreamModule, StreamModuleProcessor } from './StreamModule';
import { ProcessorModule } from './ProcessorModule';
import { MixerModule, MixerModuleProcessor } from './MixerModule';
import { MIDI } from './MIDI';
import { MML } from './MML';
import { Analyser } from './SoundModule/Analyser';
import { Recorder, RecorderProcessor } from './SoundModule/Recorder';
import { Effector } from './SoundModule/Effectors/Effector';
import { Autopanner } from './SoundModule/Effectors/Autopanner';
import { BitCrusher } from './SoundModule/Effectors/BitCrusher';
import { Chorus } from './SoundModule/Effectors/Chorus';
import { Compressor } from './SoundModule/Effectors/Compressor';
import { Delay } from './SoundModule/Effectors/Delay';
import { Equalizer } from './SoundModule/Effectors/Equalizer';
import { Filter } from './SoundModule/Effectors/Filter';
import { Flanger } from './SoundModule/Effectors/Flanger';
import { Fuzz } from './SoundModule/Effectors/Fuzz';
import { Listener } from './SoundModule/Effectors/Listener';
import { NoiseGate } from './SoundModule/Effectors/NoiseGate';
import { NoiseSuppressor } from './SoundModule/Effectors/NoiseSuppressor';
import { OverDrive } from './SoundModule/Effectors/OverDrive';
import { Panner } from './SoundModule/Effectors/Panner';
import { Phaser } from './SoundModule/Effectors/Phaser';
import { PitchShifter } from './SoundModule/Effectors/PitchShifter';
import { Preamp } from './SoundModule/Effectors/Preamp';
import { Reverb } from './SoundModule/Effectors/Reverb';
import { Ringmodulator } from './SoundModule/Effectors/Ringmodulator';
import { Stereo } from './SoundModule/Effectors/Stereo';
import { Tremolo } from './SoundModule/Effectors/Tremolo';
import { VocalCanceler } from './SoundModule/Effectors/VocalCanceler';
import { Wah } from './SoundModule/Effectors/Wah';
import { NoiseGateProcessor } from './SoundModule/Effectors/AudioWorkletProcessors/NoiseGateProcessor';
import { NoiseSuppressorProcessor } from './SoundModule/Effectors/AudioWorkletProcessors/NoiseSuppressorProcessor';
import { PitchShifterProcessor } from './SoundModule/Effectors/AudioWorkletProcessors/PitchShifterProcessor';
import { VocalCancelerProcessor } from './SoundModule/Effectors/AudioWorkletProcessors/VocalCancelerProcessor';
export type Source = OscillatorModule | OneshotModule | NoiseModule | AudioModule | MediaModule | StreamModule | ProcessorModule | MixerModule | MIDI | MML;
export type SourceName = 'oscillator' | 'oneshot' | 'noise' | 'audio' | 'media' | 'stream' | 'processor' | 'mixer' | 'midi' | 'mml';
declare const sources: {
    [sourceName: string]: Source | null;
};
/**
 * This function gets instance of `Source`.
 * This functions is overloaded for type interface and type check.
 * @param {SourceName|string} sourceName This argument selects instance for sound source.
 * @return {Source|null}
 */
declare function XSound(sourceName: 'oscillator'): OscillatorModule;
declare function XSound(sourceName: 'oneshot'): OneshotModule;
declare function XSound(sourceName: 'noise'): NoiseModule;
declare function XSound(sourceName: 'audio'): AudioModule;
declare function XSound(sourceName: 'media'): MediaModule;
declare function XSound(sourceName: 'stream'): StreamModule;
declare function XSound(sourceName: 'processor'): ProcessorModule;
declare function XSound(sourceName: 'mixer'): MixerModule;
declare function XSound(sourceName: 'midi'): MIDI;
declare function XSound(sourceName: 'mml'): MML;
declare namespace XSound {
    var SAMPLE_RATE: number;
    var EQUAL_TEMPERAMENT: 12;
    var FREQUENCY_RATIO: 1.0594630943592953;
    var MIN_A: 27.5;
    var QUARTER_NOT: 4;
    var HALF_UP: "+";
    var HALF_DOWN: "-";
    var DOT: ".";
    var isPitchChar: typeof import("./XSound").isPitchChar;
    var computeIndex: typeof import("./XSound").computeIndex;
    var computeHz: typeof import("./XSound").computeHz;
    var computeFrequency: typeof import("./XSound").computeFrequency;
    var computePlaybackRate: typeof import("./XSound").computePlaybackRate;
    var fft: typeof import("./XSound").fft;
    var ifft: typeof import("./XSound").ifft;
    var ajax: typeof import("./XSound").ajax;
    var convertTime: typeof import("./XSound").convertTime;
    var decode: typeof import("./XSound").decode;
    var requestFullscreen: typeof import("./XSound").requestFullscreen;
    var exitFullscreen: typeof import("./XSound").exitFullscreen;
    var read: typeof import("./XSound").read;
    var drop: typeof import("./XSound").drop;
    var file: typeof import("./XSound").file;
    var toFrequencies: typeof import("./XSound").toFrequencies;
    var toTextFile: typeof import("./XSound").toTextFile;
    var Analyser: typeof import("./SoundModule/Analyser").Analyser;
    var Recorder: typeof import("./SoundModule/Recorder").Recorder;
    var Effector: typeof import("./SoundModule/Effectors/Effector").Effector;
    var Autopanner: typeof import("./SoundModule/Effectors/Autopanner").Autopanner;
    var BitCrusher: typeof import("./SoundModule/Effectors/BitCrusher").BitCrusher;
    var Chorus: typeof import("./SoundModule/Effectors/Chorus").Chorus;
    var Compressor: typeof import("./SoundModule/Effectors/Compressor").Compressor;
    var Delay: typeof import("./SoundModule/Effectors/Delay").Delay;
    var Equalizer: typeof import("./SoundModule/Effectors/Equalizer").Equalizer;
    var Filter: typeof import("./SoundModule/Effectors/Filter").Filter;
    var Flanger: typeof import("./SoundModule/Effectors/Flanger").Flanger;
    var Fuzz: typeof import("./SoundModule/Effectors/Fuzz").Fuzz;
    var Listener: typeof import("./SoundModule/Effectors/Listener").Listener;
    var NoiseGate: typeof import("./SoundModule/Effectors/NoiseGate").NoiseGate;
    var NoiseSuppressor: typeof import("./SoundModule/Effectors/NoiseSuppressor").NoiseSuppressor;
    var OverDrive: typeof import("./SoundModule/Effectors/OverDrive").OverDrive;
    var Panner: typeof import("./SoundModule/Effectors/Panner").Panner;
    var Phaser: typeof import("./SoundModule/Effectors/Phaser").Phaser;
    var PitchShifter: typeof import("./SoundModule/Effectors/PitchShifter").PitchShifter;
    var Preamp: typeof import("./SoundModule/Effectors/Preamp").Preamp;
    var Reverb: typeof import("./SoundModule/Effectors/Reverb").Reverb;
    var Ringmodulator: typeof import("./SoundModule/Effectors/Ringmodulator").Ringmodulator;
    var Stereo: typeof import("./SoundModule/Effectors/Stereo").Stereo;
    var Tremolo: typeof import("./SoundModule/Effectors/Tremolo").Tremolo;
    var VocalCanceler: typeof import("./SoundModule/Effectors/VocalCanceler").VocalCanceler;
    var Wah: typeof import("./SoundModule/Effectors/Wah").Wah;
    var setup: () => Promise<void>;
    var promise: () => Promise<typeof sources | Error>;
    var clone: () => {
        (sourceName: "oscillator"): OscillatorModule;
        (sourceName: "oneshot"): OneshotModule;
        (sourceName: "noise"): NoiseModule;
        (sourceName: "audio"): AudioModule;
        (sourceName: "media"): MediaModule;
        (sourceName: "stream"): StreamModule;
        (sourceName: "processor"): ProcessorModule;
        (sourceName: "mixer"): MixerModule;
        (sourceName: "midi"): MIDI;
        (sourceName: "mml"): MML;
        free(unusedSources: Source[]): void;
    };
    var free: (unusedSources: Source[]) => void;
    var noConflict: (deep: boolean) => typeof XSound;
    var get: () => AudioContext;
    var getCurrentTime: () => number;
}
export type { SoundModule, SoundModuleParams, SoundModuleProcessor, Module, ModuleName, OscillatorModule, OscillatorModuleParams, Glide, GlideParams, GlideType, Oscillator, OscillatorParams, OscillatorCustomType, OscillatorModuleProcessor, OneshotModule, OneshotModuleParams, OneshotSetting, OneshotSettings, OneshotErrorText, OneshotModuleProcessor, NoiseModule, NoiseModuleParams, NoiseType, NoiseModuleProcessor, AudioModule, AudioModuleParams, AudioBufferSprite, AudioModuleProcessor, MediaModule, MediaModuleParams, MediaModuleProcessor, StreamModule, StreamModuleParams, StreamModuleProcessor, MediaStreamTrackAudioSourceNode, ProcessorModule, MixerModule, MixerModuleProcessor, MIDI, MML, Part, Sequence, MMLSyntaxError, Tree, TokenType, TokenMap, Token, MMLScheduleWorkerMessageEventType, MMLScheduleWorkerMessageEventData, Analyser, AnalyserParams, Domain, DataType, FFTSize, Color, Visualizer, VisualizerParams, GraphicsApi, Gradient, Gradients, Shape, Font, GraphicsStyles, TimeOverview, TimeOverviewParams, MouseEventTypes, DragMode, DragCallbackFunction, CurrentTimeStyles, Time, TimeParams, FFT, FFTParams, SpectrumScale, Recorder, RecorderParams, RecordType, QuantizationBit, WaveExportType, Frame, Channel, RecorderProcessor, RecorderProcessorMessageEventData, Effector, Autopanner, AutopannerParams, BitCrusher, BitCrusherParams, Chorus, ChorusParams, Compressor, CompressorParams, Delay, DelayParams, EnvelopeGenerator, EnvelopeGeneratorParams, Equalizer, EqualizerParams, Filter, FilterParams, Flanger, FlangerParams, Fuzz, FuzzParams, Listener, ListenerParams, NoiseGate, NoiseGateParams, NoiseGateProcessor, NoiseSuppressor, NoiseSuppressorParams, NoiseSuppressorProcessor, OverDrive, OverDriveParams, Panner, PannerParams, Position3D, Phaser, PhaserParams, PhaserNumberOfStages, PitchShifter, PitchShifterParams, PitchShifterProcessor, Preamp, PreampParams, PreampType, PreampCurve, Marshall, MarshallParams, MarshallPreEqualizerParams, MarshallPostEqualizerParams, MesaBoogie, MesaBoogieParams, MesaBoogiePreEqualizerParams, MesaBoogiePostEqualizerParams, Fender, FenderParams, FenderPreEqualizerParams, FenderPostFilterParams, FenderSpeakerInches, CabinetParams, Reverb, ReverbParams, ReverbErrorText, Ringmodulator, RingmodulatorParams, Stereo, StereoParams, Tremolo, TremoloParams, VocalCanceler, VocalCancelerParams, VocalCancelerAlgorithm, VocalCancelerProcessor, Wah, WahParams, PitchChar, ConvertedTime, FileEvent, FileReaderType, FileReaderErrorText, FrozenArray, Inputs, Outputs, Parameters };
export { XSound, XSound as X };
//# sourceMappingURL=main.d.ts.map